### Name: shrinkcat.stat
### Title: Correlation-Adjusted t Score
### Aliases: shrinkcat.stat shrinkcat.fun
### Keywords: univar

### ** Examples

# load st library 
library("st")

# load full Khan et al (2001) data set
data(khan2001)

# create data set containing only the RMS and EWS samples
idx = which( khan2001$y == "RMS" | khan2001$y == "EWS")
X = khan2001$x[idx,]
L = factor(khan2001$y[idx])
dim(X)
L

# shrinkage cat statistic
score = shrinkcat.stat(X, L)
idx = order(abs(score), decreasing=TRUE)
idx[1:10]
# [1] 1389 1955  509 1003  246  187 2050 2046  545 1954

# compute q-values and local false discovery rates
library("fdrtool")
fdr.out = fdrtool(as.vector(score))
sum(fdr.out$qval < 0.05)
sum(fdr.out$lfdr < 0.2)

# compared with:

# shrinkage t statistic 
score = shrinkt.stat(X, L)
idx = order(abs(score), decreasing=TRUE)
idx[1:10]
# [1] 1389 1955  187  246 1003 2046 2050  509  545 1799

# student t statistic
score = studentt.stat(X, L)
idx = order(abs(score), decreasing=TRUE)
idx[1:10]
# 1] 1389 1955 1003  187  246 2050 2046 1799  509  545

# difference of means ("Fold Change")
score = diffmean.stat(X, L)
idx = order(abs(score), decreasing=TRUE)
idx[1:10]
# [1]  509  187 1372 1955  246 1954  430 1645  545  129



